pub enum ControlError {
InvalidForShortFrame {
value: u8,
},
InvalidForVariableFrame {
value: u8,
},
}Expand description
Error produced when a control field is incompatible with a frame.
Variants
InvalidForShortFrame
The control value cannot be used in a short frame.
InvalidForVariableFrame
The control value cannot be used in a variable-format frame.