pub enum ShortFrameError {
InvalidLength {
actual: usize,
},
InvalidStart {
actual: u8,
},
InvalidStop {
actual: u8,
},
InvalidChecksum {
expected: u8,
actual: u8,
},
Control(ControlError),
OutputTooSmall {
actual: usize,
},
}Expand description
Error produced while constructing, encoding, or decoding a short frame.
Variants
InvalidLength
The input length was not five bytes.
InvalidStart
The initial start byte was invalid.
InvalidStop
The final stop byte was invalid.
InvalidChecksum
The checksum did not match the frame contents.
Control(ControlError)
The control field is invalid for a short frame.
OutputTooSmall
The output buffer is shorter than five bytes.