pub enum Frame {
Ack(AckFrame),
Nack(NackFrame),
Short(ShortFrame),
Control(ControlFrame),
Long(LongFrame),
}Expand description
Any supported wired M-Bus frame.
The long variant remains inline so this type works without an allocator.
Variants
Ack(AckFrame)
A positive acknowledgement.
Nack(NackFrame)
A negative acknowledgement.
Short(ShortFrame)
A fixed-length short frame.
Control(ControlFrame)
A variable-format frame without user data.
Long(LongFrame)
A variable-format frame with user data.
Implementations
Sourceimpl Frame
impl Frame
Sourcepub fn encode_into<'a>(
&self,
output: &'a mut [u8],
) -> Result<&'a [u8], FrameEncodeError>
pub fn encode_into<'a>( &self, output: &'a mut [u8], ) -> Result<&'a [u8], FrameEncodeError>
Encodes the frame into output and returns the encoded portion.
Errors
Returns FrameEncodeError when output is shorter than Self::len.
Examples found in repository?
examples/decode_exact_no_alloc.rs (line 31)
17fn main() -> Result<(), DecodeError> {
18 let frame = decode(&[0x10, 0x5b, 0x01, 0x5c, 0x16])?;
19
20 if let Frame::Short(short) = &frame {
21 assert_eq!(
22 short.control().communication_type(),
23 CommunicationType::ReqUd2
24 );
25 assert_eq!(short.address().value(), 1);
26 }
27
28 let mut output = [0_u8; LongFrame::MAX_LEN];
29 assert_eq!(
30 frame
31 .encode_into(&mut output)
32 .expect("maximum frame buffer is large enough"),
33 [0x10, 0x5b, 0x01, 0x5c, 0x16]
34 );
35
36 Ok(())
37}Sourcepub fn encode(&self) -> Vec<u8> ⓘ
pub fn encode(&self) -> Vec<u8> ⓘ
Encodes the frame into a newly allocated vector.
Examples found in repository?
examples/decode_exact_alloc.rs (line 28)
17fn main() -> Result<(), DecodeError> {
18 let frame = decode(&[0x10, 0x5b, 0x01, 0x5c, 0x16])?;
19
20 if let Frame::Short(short) = &frame {
21 assert_eq!(
22 short.control().communication_type(),
23 CommunicationType::ReqUd2
24 );
25 assert_eq!(short.address().value(), 1);
26 }
27
28 assert_eq!(frame.encode(), [0x10, 0x5b, 0x01, 0x5c, 0x16]);
29 Ok(())
30}Trait Implementations
impl Eq for Frame
Sourceimpl From<ControlFrame> for Frame
impl From<ControlFrame> for Frame
Sourcefn from(frame: ControlFrame) -> Self
fn from(frame: ControlFrame) -> Self
Converts to this type from the input type.
Sourceimpl From<ShortFrame> for Frame
impl From<ShortFrame> for Frame
Sourcefn from(frame: ShortFrame) -> Self
fn from(frame: ShortFrame) -> Self
Converts to this type from the input type.
impl StructuralPartialEq for Frame